@@ -50,7 +50,7 @@ public:
 
 class KileTable : public TQTable
 {
-   Q_OBJECT
+   TQ_OBJECT
   
 public:
    KileTable(TQWidget *dialog, TQWidget *parent=0, const char *name=0);
@@ -64,7 +64,7 @@ signals:
 
 class ConfigStructure : public TQWidget
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 public: 
    ConfigStructure(TQWidget *parent=0, const char *name=0);
