@@ -38,7 +38,7 @@ FloatEnvironmentDialog::FloatEnvironmentDialog(TDEConfig *config, KileInfo *ki,
    
 	// environment groupbox
 	TQButtonGroup *egroup = new TQButtonGroup( i18n("Environment"),page);
-	egroup->setColumnLayout(0, Qt::Vertical );
+	egroup->setColumnLayout(0, TQt::Vertical );
 	egroup->layout()->setSpacing( 6 );
 	egroup->layout()->setMargin( 11 );
 	TQGridLayout *egrouplayout = new TQGridLayout( egroup->layout() );
@@ -52,7 +52,7 @@ FloatEnvironmentDialog::FloatEnvironmentDialog(TDEConfig *config, KileInfo *ki,
 
 	// position groupbox
 	TQButtonGroup *pgroup = new TQButtonGroup( i18n("Position"),page);
-	pgroup->setColumnLayout(0, Qt::Vertical );
+	pgroup->setColumnLayout(0, TQt::Vertical );
 	pgroup->layout()->setSpacing( 6 );
 	pgroup->layout()->setMargin( 11 );
 	TQGridLayout *pgrouplayout = new TQGridLayout( pgroup->layout() );
@@ -117,8 +117,8 @@ FloatEnvironmentDialog::FloatEnvironmentDialog(TDEConfig *config, KileInfo *ki,
 	setFocusProxy( m_edCaption );
 	
 	// signals and slots
-	connect(m_rbFigure, TQT_SIGNAL(clicked()), this, TQT_SLOT(slotEnvironmentClicked()));
-	connect(m_rbTable, TQT_SIGNAL(clicked()), this, TQT_SLOT(slotEnvironmentClicked()));
+	connect(m_rbFigure, TQ_SIGNAL(clicked()), this, TQ_SLOT(slotEnvironmentClicked()));
+	connect(m_rbTable, TQ_SIGNAL(clicked()), this, TQ_SLOT(slotEnvironmentClicked()));
 	
 }
 
