@@ -94,7 +94,7 @@ struct userItem
  **/
 class Kile : public KParts::MainWindow, public KileAppDCOPIface, public KileInfo
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 
 public:
