@@ -44,11 +44,11 @@ KileAbbrevView::KileAbbrevView(TQWidget *parent, const char *name)
 
 	m_popup = new TQPopupMenu( this );
 
-	connect(this, TQT_SIGNAL(mouseButtonClicked(int,TQListViewItem *,const TQPoint &,int)),
-	        this, TQT_SLOT(slotMouseButtonClicked(int,TQListViewItem *,const TQPoint &,int)));
+	connect(this, TQ_SIGNAL(mouseButtonClicked(int,TQListViewItem *,const TQPoint &,int)),
+	        this, TQ_SLOT(slotMouseButtonClicked(int,TQListViewItem *,const TQPoint &,int)));
 
-	connect(this, TQT_SIGNAL(contextMenu(TDEListView *,TQListViewItem *,const TQPoint &)),
-	        this, TQT_SLOT(slotContextMenu(TDEListView *,TQListViewItem *,const TQPoint &)));
+	connect(this, TQ_SIGNAL(contextMenu(TDEListView *,TQListViewItem *,const TQPoint &)),
+	        this, TQ_SLOT(slotContextMenu(TDEListView *,TQListViewItem *,const TQPoint &)));
 }
 
 KileAbbrevView::~KileAbbrevView()
@@ -161,7 +161,7 @@ void KileAbbrevView::slotContextMenu(TDEListView *, TQListViewItem *item, const
 		m_popup->insertItem(i18n("&Delete"),ALVdelete);
 	}
 	
-	connect(m_popup,  TQT_SIGNAL(activated(int)), this, TQT_SLOT(slotPopupAbbreviation(int)));
+	connect(m_popup,  TQ_SIGNAL(activated(int)), this, TQ_SLOT(slotPopupAbbreviation(int)));
 
 	// show context menu
 	m_popup->exec(pos);
@@ -266,13 +266,13 @@ KileAbbrevInputDialog::KileAbbrevInputDialog(KileAbbrevView *listview, TDEListVi
 	expansion->setBuddy(m_leExpansion);
 
 	TQRegExp reg("[a-zA-Z0-9]+");
-	TQRegExpValidator *abbrevValidator = new TQRegExpValidator(reg,TQT_TQOBJECT(this));
+	TQRegExpValidator *abbrevValidator = new TQRegExpValidator(reg,this);
 	m_leAbbrev->setValidator(abbrevValidator);
 
-	connect(m_leAbbrev,TQT_SIGNAL(textChanged(const TQString &)),
-	        this,TQT_SLOT(slotTextChanged(const TQString &)));
-	connect(m_leExpansion,TQT_SIGNAL(textChanged(const TQString &)),
-	        this,TQT_SLOT(slotTextChanged(const TQString &)));
+	connect(m_leAbbrev,TQ_SIGNAL(textChanged(const TQString &)),
+	        this,TQ_SLOT(slotTextChanged(const TQString &)));
+	connect(m_leExpansion,TQ_SIGNAL(textChanged(const TQString &)),
+	        this,TQ_SLOT(slotTextChanged(const TQString &)));
 
 	slotTextChanged(TQString());
 	m_leAbbrev->setFocus();
