@@ -101,7 +101,7 @@ struct TodoResult
 
 class Info : public TQObject
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 
 public:
@@ -219,7 +219,7 @@ protected:
  **/
 class TextInfo : public Info
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 public:
 	/**
@@ -313,7 +313,7 @@ protected:
 
 class LaTeXInfo : public TextInfo
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 
 public:
@@ -354,7 +354,7 @@ private:
 
 class BibInfo : public TextInfo
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 
 public:
@@ -373,7 +373,7 @@ public slots:
 
 class ScriptInfo : public TextInfo
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 
 public:
