@@ -23,9 +23,9 @@
 
 #include <kate/view.h>
 #include <kate/document.h>
-#include <ktexteditor/searchinterface.h>
-#include <ktexteditor/editinterfaceext.h>
-#include <klocale.h>
+#include <tdetexteditor/searchinterface.h>
+#include <tdetexteditor/editinterfaceext.h>
+#include <tdelocale.h>
 #include <kinputdialog.h>
 #include <kstandarddirs.h>
 
@@ -935,8 +935,17 @@ void EditorExtension::insertIntelligentNewline(Kate::View *view)
 	{
 		if ( m_latexCommands->isListEnv(name) )
 		{
+			
 			view->keyReturn();
-			view->insertText("\\item " );
+			
+			if ( name == "description" )
+			{
+				view->insertText("\\item[]");
+				view->cursorLeft();
+			}
+			else
+				view->insertText("\\item ");
+			
 			return;
 		}
 		else if ( m_latexCommands->isTabularEnv(name) || m_latexCommands->isMathEnv(name) )
@@ -2331,14 +2340,15 @@ bool EditorExtension::insertDoubleQuotes()
 	Kate::View *view = determineView(0L);
 	if ( !view ) return true;
 	
-	uint row,col;
-	view->cursorPositionReal(&row,&col);
 	Kate::Document *doc = view->getDoc();
 
 	if( doc && m_ki->extensions()->isTexFile(doc->url()) )
 		doc->removeSelectedText();
 	else
 		return false;
+	
+	uint row,col;
+	view->cursorPositionReal(&row,&col);
 
 	// simply insert, if we are inside a verb command
 	if ( insideVerb(view) || insideVerbatim(view) )
