@@ -40,7 +40,7 @@ namespace KileDocument
   
 class EditorExtension : public TQObject
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 
 public:
