@@ -67,8 +67,8 @@ void KJSCPUGuard::start(unsigned int ms, unsigned int i_ms)
 {
   oldAlarmHandler = signal(SIGVTALRM, alarmHandler);
   itimerval tv = {
-      { i_ms / 1000, (i_ms % 1000) * 1000 },
-      { ms / 1000, (ms % 1000) * 1000 }
+      { static_cast<time_t>( i_ms / 1000 ), static_cast<suseconds_t>( (i_ms % 1000) * 1000 ) },
+      { static_cast<time_t>( ms / 1000 ), static_cast<suseconds_t>( (ms % 1000) * 1000 ) }
   };
   setitimer(ITIMER_VIRTUAL, &tv, &oldtv);
 }
@@ -512,9 +512,9 @@ namespace KileJScript {
 		// create a local scripts directory if it doesn't exist yet
 		m_localJScriptDir = locateLocal("appdata", "scripts/", true);
 		m_jScriptDirWatch = new KDirWatch(this, "KileJScript::Manager::JScriptDirWatch");
-		connect(m_jScriptDirWatch, TQT_SIGNAL(dirty(const TQString&)), this, TQT_SLOT(scanJScriptDirectories()));
-		connect(m_jScriptDirWatch, TQT_SIGNAL(created(const TQString&)), this, TQT_SLOT(scanJScriptDirectories()));
-		connect(m_jScriptDirWatch, TQT_SIGNAL(deleted(const TQString&)), this, TQT_SLOT(scanJScriptDirectories()));
+		connect(m_jScriptDirWatch, TQ_SIGNAL(dirty(const TQString&)), this, TQ_SLOT(scanJScriptDirectories()));
+		connect(m_jScriptDirWatch, TQ_SIGNAL(created(const TQString&)), this, TQ_SLOT(scanJScriptDirectories()));
+		connect(m_jScriptDirWatch, TQ_SIGNAL(deleted(const TQString&)), this, TQ_SLOT(scanJScriptDirectories()));
  		m_jScriptDirWatch->startScan();
 	}
 
@@ -780,7 +780,7 @@ m_kileInfo->viewManager()->currentView()->down();*/
 		const KileJScript::JScript *script = m_manager->getScript(m_id);
 		Q_ASSERT(script);
 		setText(i18n("Execution of %1").arg(script->getName())); 
-		connect(this, TQT_SIGNAL(activated()), this, TQT_SLOT(executeScript()));
+		connect(this, TQ_SIGNAL(activated()), this, TQ_SLOT(executeScript()));
 	}
 
 	ScriptExecutionAction::~ScriptExecutionAction()	{
