@@ -41,7 +41,7 @@ namespace KileAction { class TagData; }
 
 class KileLyxServer : public TQObject
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 
 public:
