@@ -34,7 +34,7 @@ class KileProject;
 class KileProjectItemList;
 class KileProjectItem : public TQObject
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 
 public:
@@ -139,7 +139,7 @@ public:
  **/
 class KileProject : public TQObject
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 
 public:
