@@ -61,7 +61,7 @@ KileProjectDlgBase::KileProjectDlgBase(const TQString &caption, KileDocument::Ex
 {
 	// properties groupbox
 	m_pgroup = new TQVGroupBox(i18n("Project"), plainPage());
-	m_pgroup->setColumnLayout(0, Qt::Vertical );
+	m_pgroup->setColumnLayout(0, TQt::Vertical );
 	m_pgroup->layout()->setSpacing( 6 );
 	m_pgroup->layout()->setMargin( 11 );
 	m_pgrid = new TQGridLayout( m_pgroup->layout() );
@@ -75,7 +75,7 @@ KileProjectDlgBase::KileProjectDlgBase(const TQString &caption, KileDocument::Ex
 	
 	// extensions groupbox
 	m_egroup= new TQVGroupBox(i18n("Extensions"), plainPage());
-	m_egroup->setColumnLayout(0, Qt::Vertical );
+	m_egroup->setColumnLayout(0, TQt::Vertical );
 	m_egroup->layout()->setSpacing( 6 );
 	m_egroup->layout()->setMargin( 11 );
 	m_egrid = new TQGridLayout( m_egroup->layout() );
@@ -83,7 +83,7 @@ KileProjectDlgBase::KileProjectDlgBase(const TQString &caption, KileDocument::Ex
 
 	m_extensions = new KLineEdit(m_egroup, "le_ext");
 	TQRegExp reg("[\\. a-zA-Z0-9]+");
-	TQRegExpValidator *extValidator = new TQRegExpValidator(reg,TQT_TQOBJECT(m_egroup));
+	TQRegExpValidator *extValidator = new TQRegExpValidator(reg,m_egroup);
 	m_extensions->setValidator(extValidator);
 
 	m_sel_extensions = new KComboBox(false, m_egroup, "le_sel_ext");
@@ -98,11 +98,11 @@ KileProjectDlgBase::KileProjectDlgBase(const TQString &caption, KileDocument::Ex
 
 	fillProjectDefaults();
 
-	connect(m_sel_extensions, TQT_SIGNAL(highlighted(int)),
-		this, TQT_SLOT(slotExtensionsHighlighted(int)));
+	connect(m_sel_extensions, TQ_SIGNAL(highlighted(int)),
+		this, TQ_SLOT(slotExtensionsHighlighted(int)));
 
-	connect(m_extensions, TQT_SIGNAL(textChanged(const TQString&)),
-		this, TQT_SLOT(slotExtensionsTextChanged(const TQString&)));
+	connect(m_extensions, TQ_SIGNAL(textChanged(const TQString&)),
+		this, TQ_SLOT(slotExtensionsTextChanged(const TQString&)));
 }
 
 KileProjectDlgBase::~KileProjectDlgBase()
@@ -111,11 +111,11 @@ KileProjectDlgBase::~KileProjectDlgBase()
 
 void KileProjectDlgBase::slotExtensionsHighlighted(int index)
 {
-	disconnect(m_extensions, TQT_SIGNAL(textChanged(const TQString&)),
-		this, TQT_SLOT(slotExtensionsTextChanged(const TQString&)));
+	disconnect(m_extensions, TQ_SIGNAL(textChanged(const TQString&)),
+		this, TQ_SLOT(slotExtensionsTextChanged(const TQString&)));
 	m_extensions->setText(m_val_extensions[index]);
-	connect(m_extensions, TQT_SIGNAL(textChanged(const TQString&)),
-		this, TQT_SLOT(slotExtensionsTextChanged(const TQString&)));
+	connect(m_extensions, TQ_SIGNAL(textChanged(const TQString&)),
+		this, TQ_SLOT(slotExtensionsTextChanged(const TQString&)));
 
 	m_lbStandardExtensions->setText( m_val_standardExtensions[index] );
 }
@@ -210,7 +210,7 @@ KileNewProjectDlg::KileNewProjectDlg(KileTemplate::Manager *templateManager, Kil
 	// first groupbox
 	m_pgrid->addWidget(m_plabel, 0,0);
 	m_pgrid->addWidget(m_title, 0,2);
-	connect(m_title, TQT_SIGNAL(textChanged(const TQString&)), this, TQT_SLOT(makeProjectPath()));
+	connect(m_title, TQ_SIGNAL(textChanged(const TQString&)), this, TQ_SLOT(makeProjectPath()));
 
 	m_location = new KLineEdit(m_pgroup, "le_projectlocation");
 	m_location->setMinimumWidth(200);
@@ -232,7 +232,7 @@ KileNewProjectDlg::KileNewProjectDlg(KileTemplate::Manager *templateManager, Kil
 	m_pgrid->setColSpacing(4,8);
 	m_pgrid->setColStretch(3,1);
 
-	connect(m_pbChooseDir, TQT_SIGNAL(clicked()), this, TQT_SLOT(browseLocation()));
+	connect(m_pbChooseDir, TQ_SIGNAL(clicked()), this, TQ_SLOT(browseLocation()));
 
 	// second groupbox
 	TQVGroupBox* group2= new TQVGroupBox(i18n("File"), plainPage());
@@ -254,7 +254,7 @@ KileNewProjectDlg::KileNewProjectDlg(KileTemplate::Manager *templateManager, Kil
 	grid2->addWidget(m_file, 1,1);
 	grid2->addMultiCellWidget(m_templateIconView, 2,2, 0,1);
 	grid2->setColStretch(1,1);
-	connect(m_cb, TQT_SIGNAL(clicked()), this, TQT_SLOT(clickedCreateNewFileCb()));
+	connect(m_cb, TQ_SIGNAL(clicked()), this, TQ_SLOT(clickedCreateNewFileCb()));
 
 	// third groupbox
 	m_egrid->addWidget(m_sel_extensions, 6,0);
@@ -491,7 +491,7 @@ KileProjectOptionsDlg::KileProjectOptionsDlg(KileProject *project, KileDocument:
 
 	// third groupbox
 	TQVGroupBox* group3 = new TQVGroupBox(i18n("Properties"), plainPage());
-	group3->setColumnLayout(0, Qt::Vertical );
+	group3->setColumnLayout(0, TQt::Vertical );
 	group3->layout()->setSpacing( 6 );
 	group3->layout()->setMargin( 11 );
 	TQGridLayout *grid3 = new TQGridLayout( group3->layout() );
@@ -534,7 +534,7 @@ KileProjectOptionsDlg::KileProjectOptionsDlg(KileProject *project, KileDocument:
 	setProject(project, true);
 
 	m_ckMakeIndex = new TQCheckBox(i18n("&MakeIndex options"), group3); 
-	connect(m_ckMakeIndex, TQT_SIGNAL(toggled(bool)), this, TQT_SLOT(toggleMakeIndex(bool)));
+	connect(m_ckMakeIndex, TQ_SIGNAL(toggled(bool)), this, TQ_SLOT(toggleMakeIndex(bool)));
 	m_leMakeIndex = new KLineEdit(group3); 
 	m_ckMakeIndex->setChecked(project->useMakeIndexOptions());
 	toggleMakeIndex(m_ckMakeIndex->isChecked());
