@@ -57,7 +57,7 @@ void KileProjectViewItem::nameChanged(const TQString & name)
 
 void KileProjectViewItem::isrootChanged(bool isroot)
 {
-	KILE_DEBUG() << "TQT_SLOT isrootChanged " << text(0) << " to " << isroot << endl;
+	KILE_DEBUG() << "TQ_SLOT isrootChanged " << text(0) << " to " << isroot << endl;
 	if (isroot)
 	{
 		setPixmap(0,SmallIcon("masteritem"));
@@ -106,7 +106,7 @@ KileProjectView::KileProjectView(TQWidget *parent, KileInfo *ki) : TDEListView(p
 	addColumn(i18n("Files & Projects"),-1);
 	addColumn(i18n("Include in Archive"),10);
  	setSorting(-1);
-	setFocusPolicy(TQ_ClickFocus);
+	setFocusPolicy(TQWidget::ClickFocus);
 	header()->hide();
 	setRootIsDecorated(true);
 	setAllColumnsShowFocus(true);
@@ -115,11 +115,11 @@ KileProjectView::KileProjectView(TQWidget *parent, KileInfo *ki) : TDEListView(p
 
 	m_popup = new TDEPopupMenu(this, "projectview_popup");
 
-	connect(this, TQT_SIGNAL(contextMenu(TDEListView *, TQListViewItem *, const TQPoint & )), this,TQT_SLOT(popup(TDEListView *, TQListViewItem * , const TQPoint & )));
+	connect(this, TQ_SIGNAL(contextMenu(TDEListView *, TQListViewItem *, const TQPoint & )), this,TQ_SLOT(popup(TDEListView *, TQListViewItem * , const TQPoint & )));
 
-	connect(this, TQT_SIGNAL(executed(TQListViewItem*)), this, TQT_SLOT(slotClicked(TQListViewItem*)));
+	connect(this, TQ_SIGNAL(executed(TQListViewItem*)), this, TQ_SLOT(slotClicked(TQListViewItem*)));
 	setAcceptDrops(true);
-	connect(this, TQT_SIGNAL(dropped(TQDropEvent *, TQListViewItem *)), m_ki->docManager(), TQT_SLOT(openDroppedURLs(TQDropEvent *)));
+	connect(this, TQ_SIGNAL(dropped(TQDropEvent *, TQListViewItem *)), m_ki->docManager(), TQ_SLOT(openDroppedURLs(TQDropEvent *)));
 }
 
 void KileProjectView::slotClicked(TQListViewItem *item)
@@ -260,7 +260,7 @@ void KileProjectView::popup(TDEListView *, TQListViewItem *  item, const TQPoint
 
 				apps->insertSeparator();
 				apps->insertItem(i18n("Other..."), 0);
-				connect(apps, TQT_SIGNAL(activated(int)), this, TQT_SLOT(slotRun(int)));
+				connect(apps, TQ_SIGNAL(activated(int)), this, TQ_SLOT(slotRun(int)));
 				m_popup->insertItem(SmallIcon("fork"), i18n("&Open With"),apps);
 				insertsep = true;
 			}
@@ -284,7 +284,7 @@ void KileProjectView::popup(TDEListView *, TQListViewItem *  item, const TQPoint
 			   m_popup->insertItem(SmallIcon("project_add"),i18n("&Add to Project"), KPV_ID_ADD);
 			   insertsep = true;
 			}
-			connect(m_popup,  TQT_SIGNAL(activated(int)), this, TQT_SLOT(slotFile(int)));
+			connect(m_popup,  TQ_SIGNAL(activated(int)), this, TQ_SLOT(slotFile(int)));
 		}
 		else if (itm->type() == KileType::ProjectItem || itm->type() == KileType::ProjectExtra)
 		{
@@ -304,7 +304,7 @@ void KileProjectView::popup(TDEListView *, TQListViewItem *  item, const TQPoint
 				m_popup->insertItem(SmallIcon("project_remove"),i18n("&Remove From Project"), KPV_ID_REMOVE);
 				insertsep = true;
 			}
-   			connect(m_popup,  TQT_SIGNAL(activated(int)), this, TQT_SLOT(slotProjectItem(int)));
+   			connect(m_popup,  TQ_SIGNAL(activated(int)), this, TQ_SLOT(slotProjectItem(int)));
 		}
 		else if (itm->type() == KileType::Project)
 		{
@@ -317,7 +317,7 @@ void KileProjectView::popup(TDEListView *, TQListViewItem *  item, const TQPoint
 			m_popup->insertItem(SmallIcon("relation"),i18n("Refresh Project &Tree"), KPV_ID_BUILDTREE);
 			m_popup->insertItem(SmallIcon("configure"),i18n("Project &Options"), KPV_ID_OPTIONS);
 			m_popup->insertItem(SmallIcon("package"),i18n("&Archive"), KPV_ID_ARCHIVE);
-			connect(m_popup,  TQT_SIGNAL(activated(int)), this, TQT_SLOT(slotProject(int)));
+			connect(m_popup,  TQ_SIGNAL(activated(int)), this, TQ_SLOT(slotProject(int)));
 			insertsep = true;
 		}
 
@@ -342,15 +342,15 @@ void KileProjectView::makeTheConnection(KileProjectViewItem *item)
 		if (project==0)
 			kdWarning() << "makeTheConnection COULD NOT FIND AN PROJECT OBJECT FOR " << item->url().path() << endl;
 		else
-			connect(project, TQT_SIGNAL(nameChanged(const TQString &)), item, TQT_SLOT(nameChanged(const TQString &)));
+			connect(project, TQ_SIGNAL(nameChanged(const TQString &)), item, TQ_SLOT(nameChanged(const TQString &)));
 	}
 	else
 	{
 		KileDocument::TextInfo *docinfo = m_ki->docManager()->textInfoFor(item->url().path());
 		item->setInfo(docinfo);
 		if (docinfo ==0 ) {KILE_DEBUG() << "\tmakeTheConnection COULD NOT FIND A DOCINFO" << endl; return;}
-		connect(docinfo, TQT_SIGNAL(urlChanged(KileDocument::Info*, const KURL&)),  item, TQT_SLOT(slotURLChanged(KileDocument::Info*, const KURL&)));
-		connect(docinfo, TQT_SIGNAL(isrootChanged(bool)), item, TQT_SLOT(isrootChanged(bool)));
+		connect(docinfo, TQ_SIGNAL(urlChanged(KileDocument::Info*, const KURL&)),  item, TQ_SLOT(slotURLChanged(KileDocument::Info*, const KURL&)));
+		connect(docinfo, TQ_SIGNAL(isrootChanged(bool)), item, TQ_SLOT(isrootChanged(bool)));
 		//set the pixmap
 		item->isrootChanged(docinfo->isLaTeXRoot());
 	}
