@@ -421,9 +421,9 @@ namespace KileTool
 		//lr->setParamDict(paramDict());
 		lr->setTool(this);
 		
-		connect(lr, TQT_SIGNAL(message(int, const TQString &)), this, TQT_SLOT(sendMessage(int, const TQString &)));
-		connect(lr, TQT_SIGNAL(output(const TQString &)), this, TQT_SLOT(filterOutput(const TQString &)));
-		connect(lr, TQT_SIGNAL(done(int)), this, TQT_SLOT(finish(int)));
+		connect(lr, TQ_SIGNAL(message(int, const TQString &)), this, TQ_SLOT(sendMessage(int, const TQString &)));
+		connect(lr, TQ_SIGNAL(output(const TQString &)), this, TQ_SLOT(filterOutput(const TQString &)));
+		connect(lr, TQ_SIGNAL(done(int)), this, TQ_SLOT(finish(int)));
 	}
 
 	bool Base::installLauncher()
