@@ -13,7 +13,7 @@
 #include "kileuntitled.h"
 
 #include <tqregexp.h>
-#include <klocale.h>
+#include <tdelocale.h>
 
 TQString KileUntitled::m_untitled = i18n("Untitled");
 int KileUntitled::m_last = -1;
