@@ -75,13 +75,13 @@ void Manager::setClient(TQObject *receiver, KXMLGUIClient *client)
 	m_client = client;
 	if(NULL == m_client->actionCollection()->action("popup_pasteaslatex"))
 		new TDEAction(i18n("Paste as LaTe&X"), 0, this,
-			TQT_SLOT(pasteAsLaTeX()), m_client->actionCollection(), "popup_pasteaslatex");
+			TQ_SLOT(pasteAsLaTeX()), m_client->actionCollection(), "popup_pasteaslatex");
 	if(NULL == m_client->actionCollection()->action("popup_converttolatex"))
 		new TDEAction(i18n("Convert Selection to &LaTeX"), 0, this,
-			TQT_SLOT(convertSelectionToLaTeX()), m_client->actionCollection(), "popup_converttolatex");
+			TQ_SLOT(convertSelectionToLaTeX()), m_client->actionCollection(), "popup_converttolatex");
 	if(NULL == m_client->actionCollection()->action("popup_quickpreview"))
 		new TDEAction(i18n("&QuickPreview Selection"), 0, this,
-			TQT_SLOT(quickPreviewPopup()), m_client->actionCollection(), "popup_quickpreview");
+			TQ_SLOT(quickPreviewPopup()), m_client->actionCollection(), "popup_quickpreview");
 }
 
 void Manager::createTabs(TQWidget *parent)
@@ -89,8 +89,8 @@ void Manager::createTabs(TQWidget *parent)
 	m_widgetStack = new TQWidgetStack(parent);
 	m_emptyDropWidget = new DropWidget(parent);
 	m_widgetStack->addWidget(m_emptyDropWidget);
-	connect(m_emptyDropWidget, TQT_SIGNAL(testCanDecode(const TQDragMoveEvent *,  bool &)), this, TQT_SLOT(testCanDecodeURLs(const TQDragMoveEvent *, bool &)));
-	connect(m_emptyDropWidget, TQT_SIGNAL(receivedDropEvent(TQDropEvent *)), m_ki->docManager(), TQT_SLOT(openDroppedURLs(TQDropEvent *)));
+	connect(m_emptyDropWidget, TQ_SIGNAL(testCanDecode(const TQDragMoveEvent *,  bool &)), this, TQ_SLOT(testCanDecodeURLs(const TQDragMoveEvent *, bool &)));
+	connect(m_emptyDropWidget, TQ_SIGNAL(receivedDropEvent(TQDropEvent *)), m_ki->docManager(), TQ_SLOT(openDroppedURLs(TQDropEvent *)));
 	m_tabs = new KTabWidget(parent);
 	m_widgetStack->addWidget(m_tabs);
 	m_tabs->setFocusPolicy(TQWidget::ClickFocus);
@@ -98,13 +98,13 @@ void Manager::createTabs(TQWidget *parent)
 	m_tabs->setHoverCloseButton(true);
 	m_tabs->setHoverCloseButtonDelayed(true);
 	m_tabs->setFocus();
-	connect( m_tabs, TQT_SIGNAL( currentChanged( TQWidget * ) ), m_receiver, TQT_SLOT(newCaption()) );
-	connect( m_tabs, TQT_SIGNAL( currentChanged( TQWidget * ) ), m_receiver, TQT_SLOT(activateView( TQWidget * )) );
-	connect( m_tabs, TQT_SIGNAL( currentChanged( TQWidget * ) ), m_receiver, TQT_SLOT(updateModeStatus()) );
-	connect( m_tabs, TQT_SIGNAL( closeRequest(TQWidget *) ), this, TQT_SLOT(closeWidget(TQWidget *)));
-	connect( m_tabs, TQT_SIGNAL( testCanDecode( const TQDragMoveEvent *,  bool & ) ), this, TQT_SLOT(testCanDecodeURLs( const TQDragMoveEvent *, bool & )) );
-	connect( m_tabs, TQT_SIGNAL( receivedDropEvent( TQDropEvent * ) ), m_ki->docManager(), TQT_SLOT(openDroppedURLs( TQDropEvent * )) );
-	connect( m_tabs, TQT_SIGNAL( receivedDropEvent( TQWidget*, TQDropEvent * ) ), this, TQT_SLOT(replaceLoadedURL( TQWidget *, TQDropEvent * )) );
+	connect( m_tabs, TQ_SIGNAL( currentChanged( TQWidget * ) ), m_receiver, TQ_SLOT(newCaption()) );
+	connect( m_tabs, TQ_SIGNAL( currentChanged( TQWidget * ) ), m_receiver, TQ_SLOT(activateView( TQWidget * )) );
+	connect( m_tabs, TQ_SIGNAL( currentChanged( TQWidget * ) ), m_receiver, TQ_SLOT(updateModeStatus()) );
+	connect( m_tabs, TQ_SIGNAL( closeRequest(TQWidget *) ), this, TQ_SLOT(closeWidget(TQWidget *)));
+	connect( m_tabs, TQ_SIGNAL( testCanDecode( const TQDragMoveEvent *,  bool & ) ), this, TQ_SLOT(testCanDecodeURLs( const TQDragMoveEvent *, bool & )) );
+	connect( m_tabs, TQ_SIGNAL( receivedDropEvent( TQDropEvent * ) ), m_ki->docManager(), TQ_SLOT(openDroppedURLs( TQDropEvent * )) );
+	connect( m_tabs, TQ_SIGNAL( receivedDropEvent( TQWidget*, TQDropEvent * ) ), this, TQ_SLOT(replaceLoadedURL( TQWidget *, TQDropEvent * )) );
 	m_widgetStack->raiseWidget(m_emptyDropWidget); // there are no tabs, so show the DropWidget
 }
 
@@ -142,26 +142,26 @@ Kate::View* Manager::createTextView(KileDocument::TextInfo *info, int index)
 	m_tabs->showPage( view );
 	m_textViewList.insert((index < 0 || (uint)index >= m_textViewList.count()) ? m_textViewList.count() : index, view);
 
-	connect(view, TQT_SIGNAL(viewStatusMsg(const TQString&)), m_receiver, TQT_SLOT(newStatus(const TQString&)));
-	connect(view, TQT_SIGNAL(newStatus()), m_receiver, TQT_SLOT(newCaption()));
-	connect(view, TQT_SIGNAL(dropEventPass(TQDropEvent *)), m_ki->docManager(), TQT_SLOT(openDroppedURLs(TQDropEvent *)));
-	connect(info, TQT_SIGNAL(urlChanged(KileDocument::Info*, const KURL&)), this, TQT_SLOT(urlChanged(KileDocument::Info*, const KURL&)));
+	connect(view, TQ_SIGNAL(viewStatusMsg(const TQString&)), m_receiver, TQ_SLOT(newStatus(const TQString&)));
+	connect(view, TQ_SIGNAL(newStatus()), m_receiver, TQ_SLOT(newCaption()));
+	connect(view, TQ_SIGNAL(dropEventPass(TQDropEvent *)), m_ki->docManager(), TQ_SLOT(openDroppedURLs(TQDropEvent *)));
+	connect(info, TQ_SIGNAL(urlChanged(KileDocument::Info*, const KURL&)), this, TQ_SLOT(urlChanged(KileDocument::Info*, const KURL&)));
 
-	connect( doc,  TQT_SIGNAL(charactersInteractivelyInserted (int,int,const TQString&)), m_ki->editorExtension()->complete(),  TQT_SLOT(slotCharactersInserted(int,int,const TQString&)) );
-	connect( view, TQT_SIGNAL(completionDone(KTextEditor::CompletionEntry)), m_ki->editorExtension()->complete(),  TQT_SLOT( slotCompletionDone(KTextEditor::CompletionEntry)) );
-	connect( view, TQT_SIGNAL(completionAborted()), m_ki->editorExtension()->complete(),  TQT_SLOT( slotCompletionAborted()) );
-	connect( view, TQT_SIGNAL(filterInsertString(KTextEditor::CompletionEntry*,TQString *)), m_ki->editorExtension()->complete(),  TQT_SLOT(slotFilterCompletion(KTextEditor::CompletionEntry*,TQString *)) );
+	connect( doc,  TQ_SIGNAL(charactersInteractivelyInserted (int,int,const TQString&)), m_ki->editorExtension()->complete(),  TQ_SLOT(slotCharactersInserted(int,int,const TQString&)) );
+	connect( view, TQ_SIGNAL(completionDone(KTextEditor::CompletionEntry)), m_ki->editorExtension()->complete(),  TQ_SLOT( slotCompletionDone(KTextEditor::CompletionEntry)) );
+	connect( view, TQ_SIGNAL(completionAborted()), m_ki->editorExtension()->complete(),  TQ_SLOT( slotCompletionAborted()) );
+	connect( view, TQ_SIGNAL(filterInsertString(KTextEditor::CompletionEntry*,TQString *)), m_ki->editorExtension()->complete(),  TQ_SLOT(slotFilterCompletion(KTextEditor::CompletionEntry*,TQString *)) );
 
 	// install a working kate part popup dialog thingy
 	TQPopupMenu *viewPopupMenu = (TQPopupMenu*)(m_client->factory()->container("tdetexteditor_popup", m_client));
 	if((NULL != view) && (NULL != viewPopupMenu))
 		view->installPopup(viewPopupMenu);
 	if(NULL != viewPopupMenu)
-		connect(viewPopupMenu, TQT_SIGNAL(aboutToShow()), this, TQT_SLOT(onKatePopupMenuRequest()));
+		connect(viewPopupMenu, TQ_SIGNAL(aboutToShow()), this, TQ_SLOT(onKatePopupMenuRequest()));
 
 	//activate the newly created view
 	emit(activateView(view, false));
-	TQTimer::singleShot(0, m_receiver, TQT_SLOT(newCaption())); //make sure the caption gets updated
+	TQTimer::singleShot(0, m_receiver, TQ_SLOT(newCaption())); //make sure the caption gets updated
 	
 	reflectDocumentStatus(view->getDoc(), false, 0);
 
@@ -176,15 +176,15 @@ Kate::View* Manager::createTextView(KileDocument::TextInfo *info, int index)
 	if ( action ) 
 	{
 		KILE_DEBUG() << "   reconnect action 'file_save'..." << endl;
-		action->disconnect(TQT_SIGNAL(activated()));
-		connect(action, TQT_SIGNAL(activated()), m_ki->docManager(), TQT_SLOT(fileSave()));
+		action->disconnect(TQ_SIGNAL(activated()));
+		connect(action, TQ_SIGNAL(activated()), m_ki->docManager(), TQ_SLOT(fileSave()));
 	}
 	action = view->actionCollection()->action(KStdAction::stdName(KStdAction::SaveAs));
 	if ( action ) 
 	{
 		KILE_DEBUG() << "   reconnect action 'file_save_as'..." << endl;
-		action->disconnect(TQT_SIGNAL(activated()));
-		connect(action, TQT_SIGNAL(activated()), m_ki->docManager(), TQT_SLOT(fileSaveAs()));
+		action->disconnect(TQ_SIGNAL(activated()));
+		connect(action, TQ_SIGNAL(activated()), m_ki->docManager(), TQ_SLOT(fileSaveAs()));
 	}
 	m_widgetStack->raiseWidget(m_tabs); // there is at least one tab, so show the KTabWidget now
 
@@ -201,7 +201,7 @@ void Manager::removeView(Kate::View *view)
 		m_textViewList.remove(view);
 		delete view;
 		
-		TQTimer::singleShot(0, m_receiver, TQT_SLOT(newCaption())); //make sure the caption gets updated
+		TQTimer::singleShot(0, m_receiver, TQ_SLOT(newCaption())); //make sure the caption gets updated
 		if (textViews().isEmpty()) {
 			m_ki->structureWidget()->clear();
 			m_widgetStack->raiseWidget(m_emptyDropWidget); // there are no tabs left, so show
