@@ -199,7 +199,7 @@ NewLatexCommand::NewLatexCommand(TQWidget *parent, const TQString &caption,
 			pattern = "\\\\?[A-Za-z]+";
 		}
 		TQRegExp reg(pattern);
-		m_edName->setValidator( new TQRegExpValidator(reg,TQT_TQOBJECT(m_edName)) );
+		m_edName->setValidator( new TQRegExpValidator(reg,m_edName) );
 		m_edName->setFocus();
 	}
 	else                          // edit mode
@@ -382,13 +382,13 @@ LatexCommandsDialog::LatexCommandsDialog(TDEConfig *config, KileDocument::LatexC
 	TQWhatsThis::add(m_btnDelete,i18n("Delete an user defined environment."));
 	TQWhatsThis::add(m_btnEdit,i18n("Edit an user defined environment."));
 
-   connect(m_tab,TQT_SIGNAL(currentChanged(TQWidget*)),this,TQT_SLOT(slotPageChanged(TQWidget*)));
-	connect(m_lvEnvironments, TQT_SIGNAL(selectionChanged()),this, TQT_SLOT(slotEnableButtons()));
-	connect(m_lvCommands, TQT_SIGNAL(selectionChanged()),this, TQT_SLOT(slotEnableButtons()));
-	connect(m_btnAdd, TQT_SIGNAL(clicked()),this, TQT_SLOT(slotAddClicked()));
-	connect(m_btnDelete, TQT_SIGNAL(clicked()),this, TQT_SLOT(slotDeleteClicked()));
-	connect(m_btnEdit, TQT_SIGNAL(clicked()),this, TQT_SLOT(slotEditClicked()));
-	connect(m_cbUserDefined, TQT_SIGNAL(clicked()),this, TQT_SLOT(slotUserDefinedClicked()));
+   connect(m_tab,TQ_SIGNAL(currentChanged(TQWidget*)),this,TQ_SLOT(slotPageChanged(TQWidget*)));
+	connect(m_lvEnvironments, TQ_SIGNAL(selectionChanged()),this, TQ_SLOT(slotEnableButtons()));
+	connect(m_lvCommands, TQ_SIGNAL(selectionChanged()),this, TQ_SLOT(slotEnableButtons()));
+	connect(m_btnAdd, TQ_SIGNAL(clicked()),this, TQ_SLOT(slotAddClicked()));
+	connect(m_btnDelete, TQ_SIGNAL(clicked()),this, TQ_SLOT(slotDeleteClicked()));
+	connect(m_btnEdit, TQ_SIGNAL(clicked()),this, TQ_SLOT(slotEditClicked()));
+	connect(m_cbUserDefined, TQ_SIGNAL(clicked()),this, TQ_SLOT(slotUserDefinedClicked()));
 
 	// read config and initialize changes (add, edit or delete an entry)
 	readConfig();
