@@ -19,7 +19,7 @@
 #include <tqlabel.h>
 #include <tqtooltip.h>
 
-#include <kapp.h>
+#include <tdeapplication.h>
 #include <tdelocale.h>
 #include <tdeglobal.h>
 #include <kstandarddirs.h>
