@@ -38,7 +38,7 @@ namespace KileDialog
 
 class MathEnvironmentDialog : public Wizard  
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 
 public:
