@@ -49,13 +49,13 @@ NewFileWizard::NewFileWizard(KileTemplate::Manager *templateManager, TQWidget *p
 	if ( h == -1 ) h = height();
 
 	m_newDocumentWidget = new NewDocumentWidget(this);
-	connect(m_newDocumentWidget->templateIconView, TQT_SIGNAL(doubleClicked(TQIconViewItem *)), TQT_SLOT(slotOk()));
+	connect(m_newDocumentWidget->templateIconView, TQ_SIGNAL(doubleClicked(TQIconViewItem *)), TQ_SLOT(slotOk()));
 	m_templateManager->scanForTemplates();
 	m_newDocumentWidget->templateIconView->setTemplateManager(m_templateManager);
 	m_newDocumentWidget->templateIconView->fillWithTemplates(KileDocument::LaTeX);
 
-	connect(m_newDocumentWidget->documentTypeComboBox, TQT_SIGNAL(activated(int)), this, TQT_SLOT(slotActivated(int)));
-	connect(m_newDocumentWidget->templateIconView, TQT_SIGNAL(classFileSearchFinished()), this, TQT_SLOT(restoreSelectedIcon()));
+	connect(m_newDocumentWidget->documentTypeComboBox, TQ_SIGNAL(activated(int)), this, TQ_SLOT(slotActivated(int)));
+	connect(m_newDocumentWidget->templateIconView, TQ_SIGNAL(classFileSearchFinished()), this, TQ_SLOT(restoreSelectedIcon()));
 
 	setMainWidget(m_newDocumentWidget);
 
