@@ -32,7 +32,7 @@ class NewDocumentWidget;
 
 class NewFileWizard : public KDialogBase
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 public:
 	NewFileWizard(KileTemplate::Manager *manager, TQWidget *parent=0, const char *name=0);
