@@ -12,7 +12,7 @@ void NewToolWizard::init()
 	m_toolList = KileTool::toolList(TDEGlobal::config(), false);
 
 	//setup the Name page (page 0)
-	connect(m_leName, TQT_SIGNAL(textChanged(const TQString &)), this, TQT_SLOT(nameChanged(const TQString &)));
+	connect(m_leName, TQ_SIGNAL(textChanged(const TQString &)), this, TQ_SLOT(nameChanged(const TQString &)));
 	setNextEnabled(page(0), false);
 	setFinishEnabled(page(0), false);
 	setHelpEnabled(page(0), false);
