@@ -164,7 +164,7 @@ TQWidget *QuickDocument::setupClassOptions(TQTabWidget *tab)
 	m_cbDocumentClass->setDuplicatesEnabled(false);
 //	m_cbDocumentClass->listBox()->setVariableHeight(true);
 	gl->addWidget(m_cbDocumentClass,0,1);
-	connect(m_cbDocumentClass, TQT_SIGNAL(activated(int)), this, TQT_SLOT(slotDocumentClassChanged(int)));
+	connect(m_cbDocumentClass, TQ_SIGNAL(activated(int)), this, TQ_SLOT(slotDocumentClassChanged(int)));
 
 	label = new TQLabel(i18n("Doc&ument class:"), classOptions);
 	gl->addWidget(label,0,0);
@@ -173,12 +173,12 @@ TQWidget *QuickDocument::setupClassOptions(TQTabWidget *tab)
 	m_btnDocumentClassAdd = new KPushButton(SmallIcon("edit_add"), "", classOptions);
 	TQWhatsThis::add(m_btnDocumentClassAdd, i18n("Add current text to this list"));
 	gl->addWidget(m_btnDocumentClassAdd,0,2);
-	connect(m_btnDocumentClassAdd, TQT_SIGNAL(clicked()), this, TQT_SLOT(slotDocumentClassAdd()));
+	connect(m_btnDocumentClassAdd, TQ_SIGNAL(clicked()), this, TQ_SLOT(slotDocumentClassAdd()));
 
 	m_btnDocumentClassDelete = new KPushButton(SmallIcon("eraser"), "", classOptions);
 	TQWhatsThis::add(m_btnDocumentClassDelete, i18n("Remove current element from this list"));
 	gl->addWidget(m_btnDocumentClassDelete,0,3);
-	connect(m_btnDocumentClassDelete, TQT_SIGNAL(clicked()), this, TQT_SLOT(slotDocumentClassDelete()));
+	connect(m_btnDocumentClassDelete, TQ_SIGNAL(clicked()), this, TQ_SLOT(slotDocumentClassDelete()));
 
 	// Fontsize
 	m_cbTypefaceSize = new KComboBox(classOptions);
@@ -193,12 +193,12 @@ TQWidget *QuickDocument::setupClassOptions(TQTabWidget *tab)
 	m_btnTypefaceSizeAdd = new KPushButton(SmallIcon("edit_add"), "", classOptions);
 	TQWhatsThis::add(m_btnTypefaceSizeAdd, i18n("Add current text to this list"));
 	gl->addWidget(m_btnTypefaceSizeAdd,1,2);
-	connect(m_btnTypefaceSizeAdd, TQT_SIGNAL(clicked()), this, TQT_SLOT(slotTypefaceSizeAdd()));
+	connect(m_btnTypefaceSizeAdd, TQ_SIGNAL(clicked()), this, TQ_SLOT(slotTypefaceSizeAdd()));
 
 	m_btnTypefaceSizeDelete = new KPushButton(SmallIcon("eraser"), "", classOptions);
 	TQWhatsThis::add(m_btnTypefaceSizeDelete, i18n("Remove current element from this list"));
 	gl->addWidget(m_btnTypefaceSizeDelete,1,3);
-	connect(m_btnTypefaceSizeDelete, TQT_SIGNAL(clicked()), this, TQT_SLOT(slotTypefaceSizeDelete()));
+	connect(m_btnTypefaceSizeDelete, TQ_SIGNAL(clicked()), this, TQ_SLOT(slotTypefaceSizeDelete()));
 
 	// Papersize
 	m_cbPaperSize = new KComboBox(classOptions);
@@ -214,12 +214,12 @@ TQWidget *QuickDocument::setupClassOptions(TQTabWidget *tab)
 	m_btnPaperSizeAdd = new KPushButton(SmallIcon("edit_add"), "", classOptions);
 	TQWhatsThis::add(m_btnPaperSizeAdd, i18n("Add current text to this list"));
 	gl->addWidget(m_btnPaperSizeAdd,2,2);
-	connect(m_btnPaperSizeAdd, TQT_SIGNAL(clicked()), this, TQT_SLOT(slotPaperSizeAdd()));
+	connect(m_btnPaperSizeAdd, TQ_SIGNAL(clicked()), this, TQ_SLOT(slotPaperSizeAdd()));
 
 	m_btnPaperSizeDelete = new KPushButton(SmallIcon("eraser"), "", classOptions);
 	TQWhatsThis::add(m_btnPaperSizeDelete, i18n("Remove current element from this list"));
 	gl->addWidget(m_btnPaperSizeDelete,2,3);
-	connect(m_btnPaperSizeDelete, TQT_SIGNAL(clicked()), this, TQT_SLOT(slotPaperSizeDelete()));
+	connect(m_btnPaperSizeDelete, TQ_SIGNAL(clicked()), this, TQ_SLOT(slotPaperSizeDelete()));
 
 	// Encoding
 	m_cbEncoding = new KComboBox(classOptions);
@@ -238,10 +238,10 @@ TQWidget *QuickDocument::setupClassOptions(TQTabWidget *tab)
 	m_lvClassOptions->addColumn(i18n("Description"));
 	m_lvClassOptions->setAllColumnsShowFocus(true);
 	gl->addMultiCellWidget(m_lvClassOptions, 4,4, 1,3);
-	connect(m_lvClassOptions, TQT_SIGNAL(selectionChanged()),
-	        this, TQT_SLOT(slotEnableButtons()));
-	connect(m_lvClassOptions, TQT_SIGNAL(doubleClicked(TQListViewItem *,const TQPoint &,int)),
-	        this, TQT_SLOT(slotOptionDoubleClicked(TQListViewItem *,const TQPoint &,int)));
+	connect(m_lvClassOptions, TQ_SIGNAL(selectionChanged()),
+	        this, TQ_SLOT(slotEnableButtons()));
+	connect(m_lvClassOptions, TQ_SIGNAL(doubleClicked(TQListViewItem *,const TQPoint &,int)),
+	        this, TQ_SLOT(slotOptionDoubleClicked(TQListViewItem *,const TQPoint &,int)));
 
 	label = new TQLabel(i18n("Cl&ass options:"), classOptions);
 	label->setBuddy(m_lvClassOptions);
@@ -258,17 +258,17 @@ TQWidget *QuickDocument::setupClassOptions(TQTabWidget *tab)
 	m_btnClassOptionsAdd = new KPushButton(SmallIcon("edit_add"), i18n("&Add..."), frame);
 	TQWhatsThis::add(m_btnClassOptionsAdd, i18n("Add a new class option"));
 	hl->addWidget(m_btnClassOptionsAdd);
-	connect(m_btnClassOptionsAdd, TQT_SIGNAL(clicked()), this, TQT_SLOT(slotClassOptionAdd()));
+	connect(m_btnClassOptionsAdd, TQ_SIGNAL(clicked()), this, TQ_SLOT(slotClassOptionAdd()));
 
 	m_btnClassOptionsEdit = new KPushButton(SmallIcon("edit"), i18n("Ed&it..."), frame);
 	TQWhatsThis::add(m_btnClassOptionsEdit, i18n("Edit the current class option"));
 	hl->addWidget(m_btnClassOptionsEdit);
-	connect(m_btnClassOptionsEdit, TQT_SIGNAL(clicked()), this, TQT_SLOT(slotClassOptionEdit()));
+	connect(m_btnClassOptionsEdit, TQ_SIGNAL(clicked()), this, TQ_SLOT(slotClassOptionEdit()));
 
 	m_btnClassOptionsDelete = new KPushButton(SmallIcon("eraser"), i18n("De&lete"), frame);
 	TQWhatsThis::add(m_btnClassOptionsDelete, i18n("Remove the current class option"));
 	hl->addWidget(m_btnClassOptionsDelete);
-	connect(m_btnClassOptionsDelete, TQT_SIGNAL(clicked()), this, TQT_SLOT(slotClassOptionDelete()));
+	connect(m_btnClassOptionsDelete, TQ_SIGNAL(clicked()), this, TQ_SLOT(slotClassOptionDelete()));
 
 	return classOptions;
 }
@@ -290,14 +290,14 @@ TQWidget *QuickDocument::setupPackages(TQTabWidget *tab)
 	m_lvPackages->addColumn(i18n("Description"));
 	m_lvPackages->setAllColumnsShowFocus(true);
 	label->setBuddy(m_lvPackages);
-	connect(m_lvPackages, TQT_SIGNAL(clicked(TQListViewItem *)),
-	        this, TQT_SLOT(slotCheckParent(TQListViewItem *)));
-	connect(m_lvPackages, TQT_SIGNAL(spacePressed(TQListViewItem *)),
-	        this, TQT_SLOT(slotCheckParent(TQListViewItem *)));
-	connect(m_lvPackages, TQT_SIGNAL(selectionChanged()),
-	        this, TQT_SLOT(slotEnableButtons()));
-	connect(m_lvPackages, TQT_SIGNAL(doubleClicked(TQListViewItem *,const TQPoint &,int)),
-	        this, TQT_SLOT(slotPackageDoubleClicked(TQListViewItem *,const TQPoint &,int)));
+	connect(m_lvPackages, TQ_SIGNAL(clicked(TQListViewItem *)),
+	        this, TQ_SLOT(slotCheckParent(TQListViewItem *)));
+	connect(m_lvPackages, TQ_SIGNAL(spacePressed(TQListViewItem *)),
+	        this, TQ_SLOT(slotCheckParent(TQListViewItem *)));
+	connect(m_lvPackages, TQ_SIGNAL(selectionChanged()),
+	        this, TQ_SLOT(slotEnableButtons()));
+	connect(m_lvPackages, TQ_SIGNAL(doubleClicked(TQListViewItem *,const TQPoint &,int)),
+	        this, TQ_SLOT(slotPackageDoubleClicked(TQListViewItem *,const TQPoint &,int)));
 
 	TQWidget *frame = new TQWidget(packages);
 	vl->addWidget(frame);
@@ -306,23 +306,23 @@ TQWidget *QuickDocument::setupPackages(TQTabWidget *tab)
 
 	m_btnPackagesAdd = new KPushButton(SmallIcon("edit_add"), "&Add Package...", frame);
 	TQWhatsThis::add(m_btnPackagesAdd, i18n("Add a new package"));
-	connect(m_btnPackagesAdd, TQT_SIGNAL(clicked()), this, TQT_SLOT(slotPackageAdd()));
+	connect(m_btnPackagesAdd, TQ_SIGNAL(clicked()), this, TQ_SLOT(slotPackageAdd()));
 	hl->addWidget(m_btnPackagesAdd);
 	m_btnPackagesAddOption = new KPushButton(SmallIcon("edit_add"), i18n("Add Op&tion..."), frame);
 	TQWhatsThis::add(m_btnPackagesAddOption, i18n("Add a new package option"));
-	connect(m_btnPackagesAddOption, TQT_SIGNAL(clicked()), this, TQT_SLOT(slotPackageAddOption()));
+	connect(m_btnPackagesAddOption, TQ_SIGNAL(clicked()), this, TQ_SLOT(slotPackageAddOption()));
 	hl->addWidget(m_btnPackagesAddOption);
 	m_btnPackagesEdit = new KPushButton(SmallIcon("edit"), "Ed&it...", frame);
 	TQWhatsThis::add(m_btnPackagesEdit, i18n("Edit the current package option"));
-	connect(m_btnPackagesEdit, TQT_SIGNAL(clicked()), this, TQT_SLOT(slotPackageEdit()));
+	connect(m_btnPackagesEdit, TQ_SIGNAL(clicked()), this, TQ_SLOT(slotPackageEdit()));
 	hl->addWidget(m_btnPackagesEdit);
 	m_btnPackagesDelete = new KPushButton(SmallIcon("eraser"), i18n("De&lete"), frame);
 	TQWhatsThis::add(m_btnPackagesDelete, i18n("Remove the current package option"));
-	connect(m_btnPackagesDelete, TQT_SIGNAL(clicked()), this, TQT_SLOT(slotPackageDelete()));
+	connect(m_btnPackagesDelete, TQ_SIGNAL(clicked()), this, TQ_SLOT(slotPackageDelete()));
 	hl->addWidget(m_btnPackagesDelete);
 	m_btnPackagesReset = new KPushButton(SmallIcon("reload"), i18n("&Reset to Defaults"), frame);
 	TQWhatsThis::add(m_btnPackagesReset, i18n("Reset to the default list of packages"));
-	connect(m_btnPackagesReset, TQT_SIGNAL(clicked()), this, TQT_SLOT(slotPackageReset()));
+	connect(m_btnPackagesReset, TQ_SIGNAL(clicked()), this, TQ_SLOT(slotPackageReset()));
 	hl->addWidget(m_btnPackagesReset);
 	hl->addStretch(1);
 
