@@ -55,7 +55,7 @@ typedef TQValueListIterator<Info> TemplateListIterator;
 typedef TQValueListConstIterator<Info> TemplateListConstIterator;
 
 class Manager : public TQObject {
-	Q_OBJECT
+	TQ_OBJECT
   
 	
 	public:
@@ -135,7 +135,7 @@ private:
 };
 
 class TemplateIconView : public TDEIconView {
-	Q_OBJECT
+	TQ_OBJECT
   
 	
 	public:
