@@ -34,7 +34,7 @@ namespace KileHelp
 
 class UserHelp: public TQObject 
 {
-	Q_OBJECT
+	TQ_OBJECT
   
    
 public: 
