@@ -32,7 +32,7 @@ namespace KileDialog
 
 class UserHelpDialog : public KDialogBase 
 {
-	Q_OBJECT
+	TQ_OBJECT
   
    
 public: 
@@ -61,7 +61,7 @@ private slots:
 
 class UserHelpAddDialog : public KDialogBase 
 {
-	Q_OBJECT
+	TQ_OBJECT
   
    
 public: 
